Range-v3: ranges::v3::move_sentinel< S > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::move_sentinel< S > Struct Template Reference
Utility

## Public Member Functions
S | base () const
constexpr | move_sentinel (S s)
template<typename OS , requires = (ConvertibleTo<OS, S>())>
constexpr | move_sentinel (move_sentinel< OS > const &that)
template<typename OS , requires = (ConvertibleTo<OS, S>())>
move_sentinel & | operator= (move_sentinel< OS > const &that)